FUNCTION  FRICTIONFACTOR (ROUGHNESS, DIAMETER, VELOCITY,VISCOSITY)
	!DEC$ ATTRIBUTES DLLEXPORT:: FRICTIONFACTOR

    !-----------------------------------------------------------------------------
    !Calculates the friction factor of a pipe using Churchill's equation (1977).
    !This equation is valid for all types of flows (from laminar to turbulent).
    !
    !Written by:    Christos Samaras
    !Date:          21/03/2014
    !e-mail:        xristos.samaras@gmail.com
    !site:          http://www.myengineeringworld.net
    !-----------------------------------------------------------------------------

	IMPLICIT NONE

    !Declaring the necessary variables.
	REAL*8::  FRICTIONFACTOR,ROUGHNESS, DIAMETER, VELOCITY, VISCOSITY ,REYNOLDS, A, B, C, D

	!Calculate the Reynolds number (diameter in m, velocity in m/s, kinematic viscosity in m2/s).
	REYNOLDS = (DIAMETER * VELOCITY) / VISCOSITY

	!Calculate the intermediate variables A and B.
	A=((2.457 * LOG(1. / ((ROUGHNESS / (3.7 * DIAMETER)) + ((7. / REYNOLDS) ** 0.9)))) ** 16)
	B = (37530. / REYNOLDS) ** 16.

	!Apply the equation.
	FRICTIONFACTOR = 8. * ((((8. / REYNOLDS) ** 12.) + ((A + B) ** (-3./2.))) ** (1./12.))
	
	RETURN

END FUNCTION FRICTIONFACTOR

SUBROUTINE DOUBLEARRAY (ELEMENTS, INARRAY, OUTARRAY)
	!DEC$ ATTRIBUTES DLLEXPORT:: DOUBLEARRAY

    !---------------------------------------------------------------------
    !Receives as input a one-dimensional array and it doubles tis values.
    !
    !Written by:    Christos Samaras
    !Date:          23/03/2014
    !e-mail:        xristos.samaras@gmail.com
    !site:          http://www.myengineeringworld.net
    !---------------------------------------------------------------------
	
	IMPLICIT NONE
	
	!Declaring the necessary variables.
	INTEGER*4, INTENT(IN) :: ELEMENTS
	INTEGER*4, INTENT(IN) :: INARRAY(ELEMENTS)
	INTEGER*4, INTENT(OUT) :: OUTARRAY(ELEMENTS)
	INTEGER*4:: I
	
	!Double the values of the input array.
	OUTARRAY= 2*INARRAY

	RETURN

END
